;; Generated package description from repology.el  -*- no-byte-compile: t -*-
(define-package "repology" "1.2.4.0.20240108.130348" "Repology API access via Elisp" '((emacs "26.1")) :commit "a6b41709525e60bdac807f153a3199003ee9d50f" :url "https://elpa.gnu.org/packages/repology.html" :authors '(("Nicolas Goaziou" . "mail@nicolasgoaziou.fr")) :maintainer '("Nicolas Goaziou" . "mail@nicolasgoaziou.fr") :keywords '("web"))
